<p align="center">
  <img src="assets/fuzzy_discrete_logo.png" height="350">
</p>

FuzzyDiscreteOperators is a library to operate with discrete fuzzy operators (t-norms, t-conorms, copulas, uninorms, etc).